# dopynion

Dominion in Python

## TODO

- gérer les exceptions dans les hooks et la désactivation des joueurs (y compris dans other_players)
- utiliser le nouveau data_model dans le site web (game.py et les stratégies et le template)
